@@ -40,6 +40,13 @@ class COSEKey:
         self._object = cose_key
         return
 
+    @property
+    def key(self) -> bytes:
+        """
+        A body of the symmetric key.
+        """
+        raise NotImplementedError("Symmetric key only supports 'key' property.")
+
     @property
     def kty(self) -> int:
         """
@@ -61,6 +68,13 @@ class COSEKey:
         """
         return self._object.get(3, None)
 
+    @property
+    def crv(self) -> int:
+        """
+        A curve of the key type.
+        """
+        raise NotImplementedError("OKP and EC2 key support 'crv' property.")
+
     @property
     def key_ops(self) -> list:
         """
@@ -75,6 +89,15 @@ class COSEKey:
         """
         return self._object.get(5, None)
 
+    def to_dict(self) -> Dict[int, Any]:
+        """
+        Returns a CBOR-like structure (Dict[int, Any]) of the COSE key.
+
+        Returns:
+            Dict[int, Any]: A CBOR-like structure of the COSE key.
+        """
+        return self._object
+
     def generate_nonce(self) -> bytes:
         """
         Returns a nonce with a size suitable for the algorithm.
